@@ -15,6 +15,7 @@ from braintree.customer import Customer
 from braintree.resource_collection import ResourceCollection
 from braintree.transparent_redirect import TransparentRedirect
 from braintree.exceptions.not_found_error import NotFoundError
+from braintree.descriptor import Descriptor
 
 class Transaction(Resource):
     """
@@ -305,7 +306,7 @@ class Transaction(Resource):
     @staticmethod
     def create_signature():
         return [
-            "amount", "customer_id", "merchant_account_id", "order_id", "payment_method_token", "type",
+            "amount", "customer_id", "merchant_account_id", "order_id", "payment_method_token", "purchase_order_number", "shipping_address_id", "tax_amount", "tax_exempt", "type",
             {
                 "credit_card": [
                     "token", "cardholder_name", "cvv", "expiration_date", "expiration_month", "expiration_year", "number"
@@ -336,7 +337,8 @@ class Transaction(Resource):
                     "store_shipping_address_in_vault"
                 ]
             },
-            {"custom_fields": ["__any_key__"]}
+            {"custom_fields": ["__any_key__"]},
+            {"descriptor": ["name", "phone"]}
         ]
 
     def __init__(self, gateway, attributes):
@@ -349,6 +351,8 @@ class Transaction(Resource):
         Resource.__init__(self, gateway, attributes)
 
         self.amount = Decimal(self.amount)
+        if self.tax_amount:
+            self.tax_amount = Decimal(self.tax_amount)
         if "billing" in attributes:
             self.billing_details = Address(gateway, attributes.pop("billing"))
         if "credit_card" in attributes:
@@ -363,6 +367,8 @@ class Transaction(Resource):
             self.discounts = [Discount(gateway, discount) for discount in self.discounts]
         if "status_history" in attributes:
             self.status_history = [StatusEvent(gateway, status_event) for status_event in self.status_history]
+        if "descriptor" in attributes:
+            self.descriptor = Descriptor(gateway, attributes.pop("descriptor"))
 
     @property
     def refund_id(self):
